@@ -22,6 +22,6 @@ test_that("DispFieldSTbball correctly estimates vertical velocity", {
 
   teststack1 <- c(rast1, rast2, rast3, rast4)
   VFdf5 <- DispFieldSTbball(teststack1, lagmax = 2, 1, 9, 1, 9)
-  expect_equal(round(VFdf5$dispx, 7), 0.1111111)
+  expect_equal(round(VFdf5$dispx, 7), 1)
   expect_equal(VFdf5$dispy, 0)
 })
