@@ -9,6 +9,6 @@ test_that("DispFieldbb correctly estimates displacement", {
   rast2 <- terra::rast(Mat2)
 
   VFdf1 <- DispFieldbb(rast1, rast2, 1, 9, 1, 9)
-  expect_equal(round(VFdf1$dispx, 7), 0.1111111)
+  expect_equal(round(VFdf1$dispx, 7), 1)
   expect_equal(VFdf1$dispy, 0)
 })
